@@ -1,4 +1,3 @@
-# $Id: Server.pm 102 2008-02-07 19:21:53Z wsnyder $
 # See copyright, etc in below POD section.
 ######################################################################
 
@@ -41,11 +40,11 @@ The port number (INET) or name (UNIX) of the lock server.  Defaults to
 
 =head1 DISTRIBUTION
 
-The latest version is available from CPAN and from L<http://www.veripool.com/>.
+The latest version is available from CPAN and from L<http://www.veripool.org/>.
 
-Copyright 1999-2008 by Wilson Snyder.  This package is free software; you
+Copyright 1999-2009 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
-Lesser General Public License or the Perl Artistic License.
+Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
 =head1 AUTHORS
 
@@ -81,7 +80,7 @@ use Carp;
 # Other configurable settings.
 $Debug = 0;
 
-$VERSION = '1.481';
+$VERSION = '1.484';
 $Hostname = IPC::Locker::hostfqdn();
 
 ######################################################################
@@ -114,7 +113,7 @@ sub new {
     my $param = {@_};
     if (defined $param->{family} && $param->{family} eq 'UNIX'
 	&& !exists($param->{port})) {
-    	$self->{port} = $IPC::Locker::Default_UNIX_port;
+	$self->{port} = $IPC::Locker::Default_UNIX_port;
     }
     return $self;
 }
@@ -126,19 +125,19 @@ sub start_server {
     _timelog("Listening on $self->{port}\n") if $Debug;
     my $server;
     if ($self->{family} eq 'INET') {
-    	$server = IO::Socket::INET->new( Proto     => 'tcp',
+	$server = IO::Socket::INET->new( Proto     => 'tcp',
 					 LocalPort => $self->{port},
 					 Listen    => SOMAXCONN,
 					 Reuse     => 1)
 	    or die "$0: Error, socket: $!";
     } elsif ($self->{family} eq 'UNIX') {
-    	$server = IO::Socket::UNIX->new(Local => $self->{port},
+	$server = IO::Socket::UNIX->new(Local => $self->{port},
 					Listen    => SOMAXCONN,
 					Reuse     => 1)
 	    or die "$0: Error, socket: $!\n port=$self->{port}=";
 	$self->{unix_socket_created}=1;
     } else {
-    	die "IPC::Locker::Server:  What transport do you want to use?";
+	die "IPC::Locker::Server:  What transport do you want to use?";
     }
     $Poll = IO::Poll->new();
     $Poll->mask($server => (POLLIN | POLLERR | POLLHUP | POLLNVAL));
@@ -159,7 +158,7 @@ sub start_server {
 	my (@r, @w, @e);
 
 	my $timeout = ((scalar keys %Locks) ? $PollDelta : 2000);
-    	my $npolled = $Poll->poll($timeout);
+	my $npolled = $Poll->poll($timeout);
 	if ($npolled>0) {
 	    @r = $Poll->handles(POLLIN);
 	    @e = $Poll->handles(POLLERR | POLLHUP | POLLNVAL);
@@ -168,9 +167,9 @@ sub start_server {
 	_timelog("Poll $npolled Locks=",(scalar keys %Locks),": $#r $#w $#e $!\n") if $Debug;
         foreach my $fh (@r) {
             if ($fh == $server) {
-        	# Create a new socket
-        	my $clientfh = $server->accept;
-        	$Poll->mask($clientfh => (POLLIN | POLLERR | POLLHUP | POLLNVAL));
+		# Create a new socket
+		my $clientfh = $server->accept;
+		$Poll->mask($clientfh => (POLLIN | POLLERR | POLLHUP | POLLNVAL));
 		#
 		my $clientvar = {socket=>$clientfh,
 				 input=>'',
@@ -185,18 +184,18 @@ sub start_server {
 		my $data = '';
 		my $rc = recv($fh, $data, 1000, 0);
 		if ($data eq '') {
-        	    # we have finished with the socket
+		    # we have finished with the socket
 		    delete $Clients{$fh};
-        	    $Poll->remove($fh);
-        	    $fh->close;
- 		} else {
+		    $Poll->remove($fh);
+		    $fh->close;
+		} else {
 		    my $line = $Clients{$fh}->{input}.$data;
 		    my @lines = split /\n/, $line;
 		    if ($line =~ /\n$/) {
-		    	$Clients{$fh}->{input}='';
+			$Clients{$fh}->{input}='';
 			_timelog("Nothing Left\n") if $Debug;
 		    } else {
-		    	$Clients{$fh}->{input}=pop @lines;
+			$Clients{$fh}->{input}=pop @lines;
 			_timelog("Left: ".$Clients{$fh}->{input}."\n") if $Debug;
 		    }
 		    client_service($Clients{$fh}, \@lines);
@@ -490,7 +489,7 @@ sub exist_traffic {
     # Handle UDP responses from our $Exister->pid_request calls.
     _timelog("UDP PidStat in...\n") if $Debug;
     my ($pid,$exists,$onhost) = $Exister->recv_stat();
-    if (defined $pid && $exists) {
+    if (defined $pid && defined $exists && !$exists) {
 	# We only care about known-missing processes
 	_timelog("   UDP PidStat PID $pid no longer with us.  RIP.\n") if $Debug;
 	dead_pid($onhost,$pid);
@@ -697,7 +696,7 @@ sub DESTROY {
     my $self = shift;
     _timelog("DESTROY\n") if $Debug;
     if (($self->{family} eq 'UNIX') && $self->{unix_socket_created}){
-    	unlink $self->{port};
+	unlink $self->{port};
     }
 }
 
